/*
 * Copyright 2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.language.twirl.internal;

import org.gradle.language.base.sources.BaseLanguageSourceSet;
import org.gradle.language.twirl.TwirlImports;
import org.gradle.language.twirl.TwirlSourceSet;

/**
 * Default implementation of a TwirlSourceSet
 */
public class DefaultTwirlSourceSet extends BaseLanguageSourceSet implements TwirlSourceSet {
    private TwirlImports defaultImports = TwirlImports.SCALA;

    @Override
    protected String getTypeName() {
        return "Twirl template source";
    }

    @Override
    public TwirlImports getDefaultImports() {
        return defaultImports;
    }

    @Override
    public void setDefaultImports(TwirlImports defaultImports) {
        this.defaultImports = defaultImports;
    }
}
